pub struct CachedEncoder<const N: usize> { /* private fields */ }Expand description
A cached version of the encoder Useful to synchronize one set with multiple remotes at once (without calculating the symbols multiple times)
Implementations