Decoder

Struct Decoder 

pub struct Decoder<const N: usize, T: Symbol<N>> { /* private fields */ }
The decoder to calculate set differences

Implementations

Source

impl<'a, const N: usize, T: Symbol<N>> Decoder<N, T>

pub fn new(local: impl Iterator<Item = T>) -> Self

Create a new decoder with a local iterator of items (our set)

pub fn next_symbol(&mut self, symbol: CodedSymbol<N>) -> (bool, Vec<Peeled<T>>)

Consumes a received symbol and tries to peel as many items as possible.
Returns true when done and false if there are more items to peel