CachedEncoder

Struct CachedEncoder 

pub struct CachedEncoder<const N: usize> { /* private fields */ }
A cached version of the encoder Useful to synchronize one set with multiple remotes at once (without calculating the symbols multiple times)

Implementations

Source

impl<const N: usize> CachedEncoder<N>

pub fn new<T: Symbol<N>>(iter: impl Iterator<Item = T>) -> Self

Create a new decoder from an iterator of items

pub fn get(&mut self, index: usize) -> CodedSymbol<N>

Calculate all symbols up to index and cache them